@@ -2,23 +2,29 @@ import os
 import logging
 from sentry_sdk import capture_exception, init
 from sentry_sdk.integrations.pure_eval import PureEvalIntegration
+from sentry_sdk.integrations.logging import LoggingIntegration
 
 logger = logging.getLogger("uvicorn")
 
+sentry_logging = LoggingIntegration(level=logging.INFO, event_level=logging.ERROR)
 
-def init_sentry(sentry_integrations: list, traces_sample_rate: float, sample_rate: float):
+common_integrations = [
+    sentry_logging,
+    PureEvalIntegration(),
+]
+
+
+def init_sentry(sentry_integrations: common_integrations):
     """
     This method has to be called in the app init file (main.py).
     SENTRY_DSN, SENTRY_ENVIRONMENT and SENTRY_RELEASE must be provided in app variables.
     :param sentry_integrations:
-    :param traces_sample_rate:
-    :param sample_rate:
     :return: sentry init function
     """
     return init(
         integrations=sentry_integrations,
-        traces_sample_rate=traces_sample_rate,
-        sample_rate=sample_rate,
+        traces_sample_rate=float(os.getenv("TRACES_SAMPLE_RATE_SENTRY", 1.0)),
+        sample_rate=float(os.getenv("SAMPLE_RATE_SENTRY", 1.0)),
         traces_sampler=sampling_context,
     )
 
